==> openjfx_11.0.2+1.orig.tar.xz: openjdk-jfx-11.0.2-1/modules/javafx.web/src/main/native/Source/WebCore/svg/animation/SMILTime.cpp <==
/*
 * Copyright (C) 2008 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SMILTime.h"

#include <float.h>

using namespace WebCore;

const double SMILTime::unresolvedValue = DBL_MAX;
// Just a big value smaller than DBL_MAX. Our times are relative to 0, we don't really need the full range.
const double SMILTime::indefiniteValue = FLT_MAX;

SMILTime WebCore::operator+(const SMILTime& a, const SMILTime& b)
{
    if (a.isUnresolved() || b.isUnresolved())
        return SMILTime::unresolved();
    if (a.isIndefinite() || b.isIndefinite())
        return SMILTime::indefinite();
    return a.value() + b.value();
}

SMILTime WebCore::operator-(const SMILTime& a, const SMILTime& b)
{
    if (a.isUnresolved() || b.isUnresolved())
        return SMILTime::unresolved();
    if (a.isIndefinite() || b.isIndefinite())
        return SMILTime::indefinite();
    return a.value() - b.value();
}

SMILTime WebCore::operator*(const SMILTime& a,  const SMILTime& b)
{
    if (a.isUnresolved() || b.isUnresolved())
        return SMILTime::unresolved();
    if (!a.value() || !b.value())
        return SMILTime(0);
    if (a.isIndefinite() || b.isIndefinite())
        return SMILTime::indefinite();
    return a.value() * b.value();
}

==> openjfx_11.0.11+1.orig.tar.xz: openjdk-jfx-11.0.11-1/modules/javafx.web/src/main/native/Source/WebCore/svg/animation/SMILTime.cpp <==
/*
 * Copyright (C) 2008 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SMILTime.h"

#include <float.h>

namespace WebCore {

const double SMILTime::unresolvedValue = DBL_MAX;
// Just a big value smaller than DBL_MAX. Our times are relative to 0, we don't really need the full range.
const double SMILTime::indefiniteValue = FLT_MAX;

SMILTime operator+(const SMILTime& a, const SMILTime& b)
{
    if (a.isUnresolved() || b.isUnresolved())
        return SMILTime::unresolved();
    if (a.isIndefinite() || b.isIndefinite())
        return SMILTime::indefinite();
    return a.value() + b.value();
}

SMILTime operator-(const SMILTime& a, const SMILTime& b)
{
    if (a.isUnresolved() || b.isUnresolved())
        return SMILTime::unresolved();
    if (a.isIndefinite() || b.isIndefinite())
        return SMILTime::indefinite();
    return a.value() - b.value();
}

SMILTime operator*(const SMILTime& a,  const SMILTime& b)
{
    if (a.isUnresolved() || b.isUnresolved())
        return SMILTime::unresolved();
    if (!a.value() || !b.value())
        return SMILTime(0);
    if (a.isIndefinite() || b.isIndefinite())
        return SMILTime::indefinite();
    return a.value() * b.value();
}

} // namespace WebCore
